package sun.awt;

import java.awt.FontFormatException;
import java.awt.GraphicsEnvironment;
import java.util.Locale;
import java.util.ArrayList;
import java.util.HashMap;
import sun.awt.windows.WFontConfiguration;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;
import java.io.File;
import java.security.AccessController;
import java.security.PrivilegedAction;
import sun.font.TrueTypeFont;
import sun.font.SunFontManager;

public final class Win32FontManager extends SunFontManager
{
    private static TrueTypeFont eudcFont;
    static String fontsForPrinting;
    
    private static native String getEUDCFontFile();
    
    @Override
    public TrueTypeFont getEUDCFont() {
        return Win32FontManager.eudcFont;
    }
    
    public Win32FontManager() {
        AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                Win32FontManager.this.registerJREFontsWithPlatform(SunFontManager.jreFontDirName);
                return null;
            }
        });
    }
    
    @Override
    protected boolean useAbsoluteFontFileNames() {
        return false;
    }
    
    @Override
    protected void registerFontFile(String fileName, String[] array, int n, boolean b) {
        if (this.registeredFontFiles.contains(fileName)) {
            return;
        }
        this.registeredFontFiles.add(fileName);
        int n2;
        if (this.getTrueTypeFilter().accept(null, fileName)) {
            n2 = 0;
        }
        else if (this.getType1Filter().accept(null, fileName)) {
            n2 = 1;
        }
        else {
            return;
        }
        if (this.fontPath == null) {
            this.fontPath = this.getPlatformFontPath(Win32FontManager.noType1Font);
        }
        StringTokenizer o = new StringTokenizer(Win32FontManager.jreFontDirName + File.pathSeparator + this.fontPath, File.pathSeparator);
        int n3 = 0;
        try {
            while (n3 == 0 && o.hasMoreTokens()) {
                String nextToken = o.nextToken();
                int equals = nextToken.equals(Win32FontManager.jreFontDirName);
                File o2 = new File(nextToken, fileName);
                if (o2.canRead()) {
                    n3 = 1;
                    String absolutePath = o2.getAbsolutePath();
                    if (b) {
                        this.registerDeferredFont(fileName, absolutePath, array, n2, (boolean)equals, n);
                        break;
                    }
                    super.registerFontFile(absolutePath, array, n2, (boolean)equals, n);
                    break;
                }
                else {
                    continue;
                }
            }
        }
        catch (NoSuchElementException x) {
            System.err.println(x);
        }
        if (n3 == 0) {
            this.addToMissingFontFileList(fileName);
        }
        return;
    }
    
    @Override
    protected FontConfiguration createFontConfiguration() {
        WFontConfiguration wFontConfiguration = new WFontConfiguration(this);
        wFontConfiguration.init();
        return wFontConfiguration;
    }
    
    @Override
    public FontConfiguration createFontConfiguration(boolean b, boolean b2) {
        return new WFontConfiguration(this, b, b2);
    }
    
    @Override
    protected void populateFontFileNameMap(HashMap<String, String> hashMap, HashMap<String, String> hashMap2, HashMap<String, ArrayList<String>> hashMap3, Locale locale) {
        populateFontFileNameMap0(hashMap, hashMap2, hashMap3, locale);
    }
    
    private static native void populateFontFileNameMap0(HashMap<String, String> p0, HashMap<String, String> p1, HashMap<String, ArrayList<String>> p2, Locale p3);
    
    @Override
    protected synchronized native String getFontPath(boolean p0);
    
    @Override
    protected String[] getDefaultPlatformFont() {
        String[] array = { "Arial", "c:\\windows\\fonts" };
        final String[] platformFontDirs = this.getPlatformFontDirs(true);
        if (platformFontDirs.length > 1) {
            String s = (String)AccessController.doPrivileged(new PrivilegedAction() {
                @Override
                public Object run() {
                    int i = 0;
                    while (i < platformFontDirs.length) {
                        if (new File(platformFontDirs[i] + File.separator + "arial.ttf").exists()) {
                            return platformFontDirs[i];
                        }
                        ++i;
                    }
                    return null;
                }
            });
            if (s != null) {
                array[1] = s;
            }
        }
        else {
            array[1] = platformFontDirs[0];
        }
        array[1] = array[1] + File.separator + "arial.ttf";
        return array;
    }
    
    protected void registerJREFontsWithPlatform(String fontsForPrinting) {
        Win32FontManager.fontsForPrinting = fontsForPrinting;
    }
    
    public static void registerJREFontsForPrinting() {
        final String fontsForPrinting;
        synchronized (Win32GraphicsEnvironment.class) {
            GraphicsEnvironment.getLocalGraphicsEnvironment();
            if (Win32FontManager.fontsForPrinting == null) {
                return;
            }
            fontsForPrinting = Win32FontManager.fontsForPrinting;
            Win32FontManager.fontsForPrinting = null;
        }
        AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                File parent = new File(fontsForPrinting);
                String[] list = parent.list(SunFontManager.getInstance().getTrueTypeFilter());
                if (list == null) {
                    return null;
                }
                for (int i = 0; i < list.length; ++i) {
                    Win32FontManager.registerFontWithPlatform(new File(parent, list[i]).getAbsolutePath());
                }
                return null;
            }
        });
    }
    
    protected static native void registerFontWithPlatform(String p0);
    
    protected static native void deRegisterFontWithPlatform(String p0);
    
    @Override
    public HashMap<String, SunFontManager.FamilyDescription> populateHardcodedFileNameMap() {
        HashMap<String, SunFontManager.FamilyDescription> hashMap = new HashMap();
        SunFontManager.FamilyDescription value = new SunFontManager.FamilyDescription();
        value.familyName = "Segoe UI";
        value.plainFullName = "Segoe UI";
        value.plainFileName = "segoeui.ttf";
        value.boldFullName = "Segoe UI Bold";
        value.boldFileName = "segoeuib.ttf";
        value.italicFullName = "Segoe UI Italic";
        value.italicFileName = "segoeuii.ttf";
        value.boldItalicFullName = "Segoe UI Bold Italic";
        value.boldItalicFileName = "segoeuiz.ttf";
        hashMap.put("segoe", value);
        SunFontManager.FamilyDescription value2 = new SunFontManager.FamilyDescription();
        value2.familyName = "Tahoma";
        value2.plainFullName = "Tahoma";
        value2.plainFileName = "tahoma.ttf";
        value2.boldFullName = "Tahoma Bold";
        value2.boldFileName = "tahomabd.ttf";
        hashMap.put("tahoma", value2);
        SunFontManager.FamilyDescription value3 = new SunFontManager.FamilyDescription();
        value3.familyName = "Verdana";
        value3.plainFullName = "Verdana";
        value3.plainFileName = "verdana.TTF";
        value3.boldFullName = "Verdana Bold";
        value3.boldFileName = "verdanab.TTF";
        value3.italicFullName = "Verdana Italic";
        value3.italicFileName = "verdanai.TTF";
        value3.boldItalicFullName = "Verdana Bold Italic";
        value3.boldItalicFileName = "verdanaz.TTF";
        hashMap.put("verdana", value3);
        SunFontManager.FamilyDescription value4 = new SunFontManager.FamilyDescription();
        value4.familyName = "Arial";
        value4.plainFullName = "Arial";
        value4.plainFileName = "ARIAL.TTF";
        value4.boldFullName = "Arial Bold";
        value4.boldFileName = "ARIALBD.TTF";
        value4.italicFullName = "Arial Italic";
        value4.italicFileName = "ARIALI.TTF";
        value4.boldItalicFullName = "Arial Bold Italic";
        value4.boldItalicFileName = "ARIALBI.TTF";
        hashMap.put("arial", value4);
        SunFontManager.FamilyDescription value5 = new SunFontManager.FamilyDescription();
        value5.familyName = "Symbol";
        value5.plainFullName = "Symbol";
        value5.plainFileName = "Symbol.TTF";
        hashMap.put("symbol", value5);
        SunFontManager.FamilyDescription value6 = new SunFontManager.FamilyDescription();
        value6.familyName = "WingDings";
        value6.plainFullName = "WingDings";
        value6.plainFileName = "WINGDING.TTF";
        hashMap.put("wingdings", value6);
        return hashMap;
    }
    
    static String access$000() {
        return getEUDCFontFile();
    }
    
    static {
        AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                String access$000 = Win32FontManager.access$000();
                if (access$000 != null) {
                    try {
                        Win32FontManager.eudcFont = new TrueTypeFont(access$000, null, 0, true, false);
                    }
                    catch (FontFormatException ex) {}
                }
                return null;
            }
        });
        Win32FontManager.fontsForPrinting = null;
    }
}
